@@ -25,8 +25,8 @@
 #include "revision.h"
 #include "utils.h"
 
-#include <QtNetwork/QNetworkReply>
-#include <QtNetwork/QNetworkRequest>
+#include <QNetworkReply>
+#include <QNetworkRequest>
 
 
 using namespace KGAPI2;
